<?php
/*
 * 
 * Require the framework class before doing anything else, so we can use the defined urls and dirs
 * Also if running on windows you may have url problems, which can be fixed by defining the framework url first
 *
 */
//define('admin_OPTIONS_URL', site_url('path the options folder/'));
if(!class_exists('admin_Options')){
	require_once( dirname( __FILE__ ) . '/options/options.php' );
}


define('admin_OPTIONS_URL', ADSOFT_WFBT_URL.'admin/options/');
/*
 * 
 * Custom function for filtering the sections array given by theme, good for child themes to override or add to the sections.
 * Simply include this function in the child themes functions.php file.
 *
 * NOTE: the defined constansts for urls, and dir will NOT be available at this point in a child theme, so you must use
 * get_template_directory_uri() if you want to use any of the built in icons
 *
 */
function add_another_section($sections){
	
	//$sections = array();
	$sections[] = array(
				'title' => __('A Section added by hook', 'admin-opts'),
				'desc' => __('<p class="description">This is a section created by adding a filter to the sections array, great to allow child themes, to add/remove sections from the options.</p>', 'admin-opts'),
				//all the glyphicons are included in the options folder, so you can hook into them, or link to your own custom ones.
				//You dont have to though, leave it blank for default.
				'icon' => trailingslashit(get_template_directory_uri()).'options/img/glyphicons/glyphicons_062_attach.png',
				//Lets leave this as a blank section, no options just some intro text set above.
				'fields' => array()
				);
	
	return $sections;
	
}//function
//add_filter('admin-opts-sections-twenty_eleven', 'add_another_section');


/*
 * 
 * Custom function for filtering the args array given by theme, good for child themes to override or add to the args array.
 *
 */
function change_framework_args($args){
	
	//$args['dev_mode'] = false;
	
	return $args;
	
}//function
//add_filter('admin-opts-args-twenty_eleven', 'change_framework_args');

/*
 * This is the meat of creating the optons page
 *
 * Override some of the default values, uncomment the args and change the values
 * - no $args are required, but there there to be over ridden if needed.
 *
 *
 */

function setup_framework_options(){
$args = array();

//Set it to dev mode to view the class settings/info in the form - default is false
$args['dev_mode'] = false;

//google api key MUST BE DEFINED IF YOU WANT TO USE GOOGLE WEBFONTS
//$args['google_api_key'] = '***';

//Remove the default stylesheet? make sure you enqueue another one all the page will look whack!
//$args['stylesheet_override'] = true;

//Add HTML before the form
$args['intro_text'] = __('', 'admin-opts');

//Setup custom links in the footer for share icons
$args['share_icons']['twitter'] = array(
										'link' => 'http://twitter.com/bitset_solution',
										'title' => 'Folow us on Twitter', 
										'img' => admin_OPTIONS_URL.'img/glyphicons/glyphicons_322_twitter.png'
										);
$args['share_icons']['linked_in'] = array(
										'link' => 'http://facebook.com/bitset',
										'title' => 'Like Us', 
										'img' => admin_OPTIONS_URL.'img/glyphicons/glyphicons_320_facebook.png'
										);

//Choose to disable the import/export feature
$args['show_import_export'] = true;

//Choose a custom option name for your theme options, the default is the theme name in lowercase with spaces replaced by underscores
$args['opt_name'] = 'wfbt';

//Custom menu icon
//$args['menu_icon'] = '';

//Custom menu title for options page - default is "Options"
$args['menu_title'] = __('Settings', 'admin-opts');

//Custom Page Title for options page - default is "Options"
$args['page_title'] = __('WooCommerce - Frequently Bought Together Settings', 'admin-opts');

//Custom page slug for options page (wp-admin/themes.php?page=***) - default is "admin_theme_options"
$args['page_slug'] = 'frequently-bought-together-settings';

//Custom page capability - default is set to "manage_options"
//$args['page_cap'] = 'manage_options';

//page type - "menu" (adds a top menu section) or "submenu" (adds a submenu) - default is set to "menu"
$args['page_type'] = 'submenu';

//parent menu - default is set to "themes.php" (Appearance)
//the list of available parent menus is available here: http://codex.wordpress.org/Function_Reference/add_submenu_page#Parameters
$args['page_parent'] = 'frequently-bought-together';

//custom page location - default 100 - must be unique or will override other items
//$args['page_position'] = 56;



//Set the Help Sidebar for the options page - no sidebar by default										
$args['help_sidebar'] = __('<p>This is the sidebar content, HTML is allowed.</p>', 'admin-opts');



$sections = array();

wp_reset_query();
// Pull all the categories into an array	
$options_categories = array();  
$options_categories_obj = get_categories('title_li=&exclude=&hide_empty=0');

foreach ($options_categories_obj as $category) {
	$options_categories[$category->cat_ID] = $category->cat_name;
}

$options_pages = array();
$options_pages_obj = get_pages();
foreach ( $options_pages_obj as $pages ) {
	$include_onepage =  get_post_meta($pages->ID,'one_page',true);
	if($include_onepage == 'yes')
	{
		$options_pages[$pages->post_name] = $pages->post_title;
	}

  	
}

//General Setting
$sections[] = array(
				'title' => __('Settings', 'admin-opts'),
				'desc' => __('<p class="description">WooCommerce Frequently Bought Together Settings.</p>', 'admin-opts'),
				//all the glyphicons are included in the options folder, so you can hook into them, or link to your own custom ones.
				//You dont have to though, leave it blank for default.
				'icon' => admin_OPTIONS_URL.'img/glyphicons/glyphicons_280_settings.png',
				//Lets leave this as a blank section, no options just some intro text set above.
				'fields' => array(
					
					array(
						'id' => 'box_title',
						'type' => 'text',
						'title' => __('Box Title', 'admin-opts'), 
						'sub_desc' => __('Frequently Bought Together Box Title', 'admin-opts'),
						'desc' => __('Ex. Frequently Bought Together', 'admin-opts'),
						'std' => 'Frequently Bought Together'
						),
						
					array(
						'id' => 'box_position',
						'type' => 'select',
						'title' => __('Box Position', 'admin-opts'), 
						'sub_desc' => __('Where you want to show the frequently bought box', 'admin-opts'),
						'desc' => __('Choose an option', 'admin-opts'),
						'options' => array(
							'woocommerce_after_single_product_summary' => __('After product summary', 'admin-opts'),
							'woocommerce_after_single_product' => __('Bottom of the product page', 'admin-opts'),
							'woocommerce_after_main_content' => __('Bottom of the product content', 'admin-opts'),
							'woocommerce_before_single_product' => __('Top of the product page', 'admin-opts'),
							'woocommerce_before_single_product_summary' => __('Top of the product content', 'admin-opts'),
							'woocommerce_single_product_summary' => __('Before product title', 'admin-opts')
						),
						'std' => 'woocommerce_after_single_product_summary'
						),
						
					array(
						'id' => 'buy_label_two',
						'type' => 'text',
						'title' => __('Buy Label for Two Products', 'admin-opts'), 
						'sub_desc' => __('Set price label for two products.', 'admin-opts'),
						'desc' => __('Ex. Price for both', 'admin-opts'),
						'std' => 'Price for both'
						),
						
					array(
						'id' => 'button_label_two',
						'type' => 'text',
						'title' => __('Button Label for Two Products', 'admin-opts'), 
						'sub_desc' => __('Set button label for two products.', 'admin-opts'),
						'desc' => __('Ex. Add both to Cart', 'admin-opts'),
						'std' => 'Add both to Cart'
						),
						
					array(
						'id' => 'buy_label_three',
						'type' => 'text',
						'title' => __('Buy Label for Three Products', 'admin-opts'), 
						'sub_desc' => __('Set price label for three products', 'admin-opts'),
						'desc' => __('Ex. Price for all three', 'admin-opts'),
						'std' => 'Price for all three'
						),
						
					array(
						'id' => 'button_label_three',
						'type' => 'text',
						'title' => __('Button Label for Three Products', 'admin-opts'), 
						'sub_desc' => __('Set button label for three products.', 'admin-opts'),
						'desc' => __('Ex. Add all three to Cart', 'admin-opts'),
						'std' => 'Add all three to Cart'
						),
						
					array(
						'id' => 'buy_label_multi',
						'type' => 'text',
						'title' => __('Buy Label for Multi Products', 'admin-opts'), 
						'sub_desc' => __('Set price label for multi products', 'admin-opts'),
						'desc' => __('Ex. Price for all', 'admin-opts'),
						'std' => 'Price for all'
						),
						
					array(
						'id' => 'button_label_multi',
						'type' => 'text',
						'title' => __('Button Label for Multi Products', 'admin-opts'), 
						'sub_desc' => __('Set button label for multi products.', 'admin-opts'),
						'desc' => __('Ex. Add all to Cart', 'admin-opts'),
						'std' => 'Add all to Cart'
						),
						
					array(
						'id' => 'button_color',
						'type' => 'color',
						'title' => __('Button Color', 'admin-opts'), 
						'sub_desc' => __('Add to cart button color', 'admin-opts'),
						'desc' => __('Ex. #d94412', 'admin-opts'),
						'std' => '#d94412'
						),
						
					array(
						'id' => 'button_hover_color',
						'type' => 'color',
						'title' => __('Button Hover Color', 'admin-opts'), 
						'sub_desc' => __('Add to cart button hover color', 'admin-opts'),
						'desc' => __('Ex. #ed6a31', 'admin-opts'),
						'std' => '#ed6a31'
						),
						
					array(
						'id' => 'button_text_color',
						'type' => 'color',
						'title' => __('Button Text Color', 'admin-opts'), 
						'sub_desc' => __('Add to cart button text color', 'admin-opts'),
						'desc' => __('Ex. #ffffff', 'admin-opts'),
						'std' => '#ffffff'
						),
						
					array(
						'id' => 'button_text_hover_color',
						'type' => 'color',
						'title' => __('Button Text Hover Color', 'admin-opts'), 
						'sub_desc' => __('Add to cart button text hover color', 'admin-opts'),
						'desc' => __('Ex. #ffffff', 'admin-opts'),
						'std' => '#ffffff'
						)
					)
				);
				
	$tabs = array();

	global $admin_Options;
	$admin_Options = new nhp_Options($sections, $args, $tabs);

}//function
add_action('init', 'setup_framework_options',0);

/*
 * 
 * Custom function for the callback referenced above
 *
 */
function my_custom_field($field, $value){
	print_r($field);
	print_r($value);

}//function

/*
 * 
 * Custom function for the callback validation referenced above
 *
 */
function validate_callback_function($field, $value, $existing_value){
	
	$error = false;
	$value =  'just testing';
	/*
	do your validation
	
	if(something){
		$value = $value;
	}elseif(somthing else){
		$error = true;
		$value = $existing_value;
		$field['msg'] = 'your custom error message';
	}
	*/
	
	$return['value'] = $value;
	if($error == true){
		$return['error'] = $field;
	}
	return $return;
	
}//function
?>