<?php
/**
 * Form template
 * @version 1.0.0
 */

global $product, $woozoom_options;
$wfbt_ops = get_option('wfbt');

$index  = 0;
$thumbs = $checks = '';
$total  = 0;

if( ! isset( $args ) ) {
	return;
}

// set query
$url = add_query_arg( 'adsoft_bought_together' , $product->id, get_permalink( $product->id ) );
$url = wp_nonce_url( $url, 'action_bought_together' );


foreach( $args as $arg ) {

	if( get_post_type( $arg ) != 'product' && get_post_type( $arg ) != 'product_variation' ) {
		continue;
	}

	$current = wc_get_product( $arg );

	if( ! $current || ! $current->is_in_stock() ) {
		continue;
	}

	// get correct id if product is variation
	$id = $current->product_type == 'variation' ? $current->variation_id : $current->id;

	if( $index > 0 )
		$thumbs .= '<td class="image_plus image_plus_' . $index . '" data-rel="offeringID_' . $index . '">+</td>';
	$thumbs .= '<td class="image-td" data-rel="offeringID_' . $index . '"><a href="' . get_permalink( $current->id ) . '">' . $current->get_image( 'shop_thumbnail' ) . '</a></td>';

	ob_start();
	?>
	<li class="adsoft-wfbt-item">
		<label for="offeringID_<?php echo $index ?>">

			<input type="hidden" name="offeringID[]" id="offeringID_<?php echo $index ?>" class="active" value="<?php echo $id ?>" />

			<span class="product-name">
				<?php echo '<a href="' . get_permalink( $current->id ) . '">';?>
				<?php echo ! $index ? __( 'This Product', 'adsoft' ) . ': ' . $current->get_title() : $current->get_title(); ?>
				<?php echo '</a>';?>
			</span>

			<?php

			if( $current->product_type == 'variation' ) {
				$attributes = $current->get_variation_attributes();
				$variations = array();

				foreach( $attributes as $key => $attribute ) {
					$key = str_replace( 'attribute_', '', $key );

					$terms = get_terms( sanitize_title( $key ), array(
						'menu_order' => 'ASC',
						'hide_empty' => false
					) );

					foreach ( $terms as $term ) {
						if ( ! is_object( $term ) || ! in_array( $term->slug, array( $attribute ) ) ) {
							continue;
						}
						$variations[] = $term->name;
					}
				}

				if( ! empty( $variations ) )
					echo '<span class="product-attributes"> &ndash; ' . implode( ', ', $variations ) . '</span>';
			}

			// echo product price
			echo ' &ndash; <span class="price">' . $current->get_price_html() . '</span>';
			?>

		</label>
	</li>
	<?php
	$checks .= ob_get_clean();
	// increment total
	$total += floatval( $current->get_display_price() );

	// increment index
	$index++;
}

if( $index < 2 ) {
	return; // exit if only available product is current
}

// set button label
$title = ($wfbt_ops['box_title'] == '') ? 'Frequently Bought Together' : $wfbt_ops['box_title'];

if( $index == 2 ) {
	$label_total = ($wfbt_ops['buy_label_two'] == '') ? 'Price for both' : $wfbt_ops['buy_label_two'];
	$label = ($wfbt_ops['button_label_two'] == '') ? 'Add both to Cart' : $wfbt_ops['button_label_two'];
} else if( $index == 3 ) {
	$label_total = ($wfbt_ops['buy_label_three'] == '') ? 'Price for all three' : $wfbt_ops['buy_label_three'];
	$label = ($wfbt_ops['button_label_three'] == '') ? 'Add all three to Cart' : $wfbt_ops['button_label_three'];
} else {
	$label_total = ($wfbt_ops['buy_label_multi'] == '') ? 'Price for all' : $wfbt_ops['buy_label_multi'];
	$label = ($wfbt_ops['button_label_multi'] == '') ? 'Add all to Cart' : $wfbt_ops['button_label_multi'];	
} 
?>

<div class="adsoft-wfbt-section">
	<?php if( $title != '' ) {
		echo '<h3>' . esc_html( $title ) . '</h3>';
	}
	?>

	<form class="adsoft-wfbt-form" method="post" action="<?php echo esc_url( $url ) ?>">

		<table class="adsoft-wfbt-images">
			<tbody>
				<tr>
					<?php echo $thumbs ?>
				</tr>
			</tbody>
		</table>

		<div class="adsoft-wfbt-submit-block">
			<div class="price_text">
				<span class="total_price_label">
					<?php echo esc_html( $label_total ) ?>:
				</span>
				&nbsp;
				<span class="total_price" data-total="<?php echo $total ?>">
					<?php echo wc_price( $total ) ?>
				</span>
			</div>
			<input type="submit" class="adsoft-wfbt-submit-button" value="<?php echo esc_html( $label ); ?>">
		</div>

		<ul class="adsoft-wfbt-items">
			<?php echo $checks ?>
		</ul>

	</form>
</div>