<?php
/**
 * Admin class
 * @version 1.0.0
 */

if ( ! defined( 'ADSOFT_WFBT' ) ) {
	exit;
} // Exit if accessed directly

if ( ! class_exists( 'ADSOFT_WFBT_Admin' ) ) {
	/**
	 * Admin class.
	 * The class manage all the admin behaviors.
	 *
	 * @since 1.0.0
	 */
	class ADSOFT_WFBT_Admin {

		/**
		 * Single instance of the class
		 *
		 * @var \ADSOFT_WFBT_Admin
		 * @since 1.0.0
		 */
		protected static $instance;

		/**
		 * Plugin options
		 *
		 * @var array
		 * @access public
		 * @since 1.0.0
		 */
		public $options = array();

		/**
		 * Returns single instance of the class
		 *
		 * @return \ADSOFT_WFBT_Admin
		 * @since 1.0.0
		 */
		public static function get_instance(){
			if( is_null( self::$instance ) ){
				self::$instance = new self();
			}

			return self::$instance;
		}

		/**
		 * Constructor
		 *
		 * @access public
		 * @since 1.0.0
		 */
		public function __construct() {
			// add section in product edit page
			add_filter( 'woocommerce_product_data_tabs', array( $this, 'add_bought_together_tab' ), 10, 1 );
			add_action( 'woocommerce_product_data_panels', array( $this, 'add_bought_together_panel') );

			// search product
			add_action( 'wp_ajax_adsoft_ajax_search_product', array( $this, 'adsoft_ajax_search_product' ) );
			add_action( 'wp_ajax_nopriv_adsoft_ajax_search_product', array( $this, 'adsoft_ajax_search_product' ) );
			// save tabs options
			add_action( 'woocommerce_process_product_meta_simple', array( $this, 'save_bought_together_tab' ), 10, 1 );
			add_action( 'woocommerce_process_product_meta_variable', array( $this, 'save_bought_together_tab' ), 10, 1 );
			add_action( 'woocommerce_process_product_meta_grouped', array( $this, 'save_bought_together_tab' ), 10, 1 );
			add_action( 'woocommerce_process_product_meta_external', array( $this, 'save_bought_together_tab' ), 10, 1 );
		}

		/**
		 * Add bought together tab in edit product page
		 */
		public function add_bought_together_tab( $tabs ){

			$tabs['adsoft-wfbt'] = array(
				'label'  => __( 'Frequently Bought Together', 'adsoft' ),
				'target' => 'adsoft_wfbt_data_option',
				'class'  => array( 'hide_if_grouped', 'hide_if_external' ),
			);

			return $tabs;
		}

		/**
		 * Add bought together panel in edit product page
		 */
		public function add_bought_together_panel(){

			global $post;

			?>

			<div id="adsoft_wfbt_data_option" class="panel woocommerce_options_panel">

				<div class="options_group">

					<p class="form-field"><label for="adsoft_wfbt_ids"><?php _e( 'Select products', 'adsoft' ); ?></label>
						<input type="hidden" class="wc-product-search" style="width: 50%;" id="adsoft_wfbt_ids" name="adsoft_wfbt_ids" data-placeholder="<?php _e( 'Search for a product&hellip;', 'adsoft' ); ?>" data-multiple="true" data-action="adsoft_ajax_search_product" data-selected="<?php
						$product_ids = array_filter( array_map( 'absint', (array) get_post_meta( $post->ID, ADSOFT_WFBT_META, true ) ) );
						$json_ids    = array();

						foreach ( $product_ids as $product_id ) {
							$product = wc_get_product( $product_id );
							if ( is_object( $product ) ) {
								$json_ids[ $product_id ] = wp_kses_post( html_entity_decode( $product->get_formatted_name() ) );
							}
						}

						echo esc_attr( json_encode( $json_ids ) );
						?>" value="<?php echo implode( ',', array_keys( $json_ids ) ); ?>" />
						<img class="help_tip" data-tip='<?php _e( 'Select products for "Frequently bought together" group', 'adsoft' ) ?>' src="<?php echo WC()->plugin_url(); ?>/assets/images/help.png" height="16" width="16" />
					</p>

				</div>

			</div>

			<?php
		}

		/**
		 * Ajax action search product
		 */
		public function adsoft_ajax_search_product(){

			ob_start();

			check_ajax_referer( 'search-products', 'security' );

			$term = (string) wc_clean( stripslashes( $_GET['term'] ) );
			$post_types = array( 'product', 'product_variation' );

			if ( empty( $term ) ) {
				die();
			}

			$args = array(
				'post_type'      => $post_types,
				'post_status'    => 'publish',
				'posts_per_page' => -1,
				's'              => $term,
				'fields'         => 'ids'
			);

			if ( is_numeric( $term ) ) {

				$args2 = array(
					'post_type'      => $post_types,
					'post_status'    => 'publish',
					'posts_per_page' => -1,
					'post__in'       => array( 0, $term ),
					'fields'         => 'ids'
				);

				$args3 = array(
					'post_type'      => $post_types,
					'post_status'    => 'publish',
					'posts_per_page' => -1,
					'post_parent'    => $term,
					'fields'         => 'ids'
				);

				$args4 = array(
					'post_type'      => $post_types,
					'post_status'    => 'publish',
					'posts_per_page' => -1,
					'meta_query'     => array(
						array(
							'key'     => '_sku',
							'value'   => $term,
							'compare' => 'LIKE'
						)
					),
					'fields'         => 'ids'
				);

				$posts = array_unique( array_merge( get_posts( $args ), get_posts( $args2 ), get_posts( $args3 ), get_posts( $args4 ) ) );

			} else {

				$args2 = array(
					'post_type'      => $post_types,
					'post_status'    => 'publish',
					'posts_per_page' => -1,
					'meta_query'     => array(
						array(
							'key'     => '_sku',
							'value'   => $term,
							'compare' => 'LIKE'
						)
					),
					'fields'         => 'ids'
				);

				$posts = array_unique( array_merge( get_posts( $args ), get_posts( $args2 ) ) );

			}

			$found_products = array();

			if ( $posts ) {
				foreach ( $posts as $post ) {
					$product = wc_get_product( $post );
					// exclude variable product
					if( $product->product_type == 'variable' ) {
						continue;
					}

					$found_products[ $post ] = rawurldecode( $product->get_formatted_name() );
				}
			}

			wp_send_json( $found_products );
		}

		/**
		 * Save options in upselling tab
		 */
		public function save_bought_together_tab( $post_id ){

			// save products group
			$products = isset( $_POST['adsoft_wfbt_ids'] ) ? array_filter( array_map( 'intval', explode( ',', $_POST['adsoft_wfbt_ids'] ) ) ) : array();
			update_post_meta( $post_id, ADSOFT_WFBT_META, $products );

		}

	}
}
/**
 * Unique access to instance of ADSOFT_WFBT_Admin class
 */
function ADSOFT_WFBT_Admin(){
	return ADSOFT_WFBT_Admin::get_instance();
}