<?php
/**
 * Frontend class
 */

if ( ! defined( 'ADSOFT_WFBT' ) ) {
	exit;
} // Exit if accessed directly

if ( ! class_exists( 'ADSOFT_WFBT_Frontend' ) ) {
	/**
	 * Frontend class.
	 * The class manage all the frontend behaviors.
	 *
	 * @since 1.0.0
	 */
	class ADSOFT_WFBT_Frontend {

		/**
		 * Single instance of the class
		 *
		 * @var \ADSOFT_WFBT_Frontend
		 * @since 1.0.0
		 */
		protected static $instance;

		/**
		 * Returns single instance of the class
		 *
		 * @return \ADSOFT_WFBT_Frontend
		 * @since 1.0.0
		 */
		public static function get_instance(){
			if( is_null( self::$instance ) ){
				self::$instance = new self();
			}

			return self::$instance;
		}

		/**
		 * Constructor
		 */
		public function __construct() {

			global $woozoom_options;
			$wfbt_ops = get_option('wfbt');
			
			// enqueue scripts
			add_action( 'wp_enqueue_scripts', array( $this, 'enqueue_scripts' ) );
			
			$box_position = ($wfbt_ops['box_position'] == '') ? 'woocommerce_after_single_product_summary' : $wfbt_ops['box_position'];
			add_action( $box_position, array( $this, 'add_bought_together_form' ), 1 );
		}

		/**
		 * Enqueue scripts
		 */
		public function enqueue_scripts(){

			global $woozoom_options;
			$wfbt_ops = get_option('wfbt');
			
			wp_enqueue_style( 'adsoft-wfbt-style', ADSOFT_WFBT_URL . '/assets/css/adsoft-wfbt.css' );

			$background = ($wfbt_ops['button_color'] == '') ? '#d94412' : $wfbt_ops['button_color'];
			$background_hover = ($wfbt_ops['button_hover_color'] == '') ? '#ed6a31' : $wfbt_ops['button_hover_color'];
			$text_color = ($wfbt_ops['button_text_color'] == '') ? '#ffffff' : $wfbt_ops['button_text_color'];
			$text_color_hover = ($wfbt_ops['button_text_hover_color'] == '') ? '#ffffff' : $wfbt_ops['button_text_hover_color'];
			
			$inline_css = "
                .adsoft-wfbt-submit-block .adsoft-wfbt-submit-button {
                        background: {$background};
                        color: {$text_color};
                }
                .adsoft-wfbt-submit-block .adsoft-wfbt-submit-button:hover {
                        background: {$background_hover};
                        color: {$text_color_hover};
                }";

			wp_add_inline_style( 'adsoft-wfbt-style', $inline_css );
		}

		/**
		 * Form Template
		 */
		public function add_bought_together_form(){

			global $product;

			// get meta for current product
			$group  = get_post_meta( $product->id, ADSOFT_WFBT_META, true );

			if( empty( $group ) || $product->product_type == 'grouped' || $product->product_type == 'external' ) {
				return;
			}

			$product_id = $product->id;

			if( $product->product_type == 'variable' ) {

				$variations = $product->get_children();

				if( empty( $variations ) ) {
					return;
				}
				// get first product variation
				$product_id = array_shift( $variations );
			}

			// merge array
			$group = array_merge( array( $product_id ), $group );

			wc_get_template( 'adsoft-wfbt-form.php', $group, '', ADSOFT_WFBT_DIR . 'includes/' );
		}
	}
}
/**
 * Unique access to instance of ADSOFT_WFBT_Frontend class
 *
 * @return \ADSOFT_WFBT_Frontend
 * @since 1.0.0
 */
function ADSOFT_WFBT_Frontend(){
	return ADSOFT_WFBT_Frontend::get_instance();
}