<?php
/**
 * Main class
 * @version 1.0.0
 */
if ( ! defined( 'ADSOFT_WFBT' ) ) {
	exit;
} // Exit if accessed directly

if ( ! class_exists( 'ADSOFT_WFBT' ) ) {
	/**
	 * YITH WooCommerce Frequently Bought Together Premium
	 *
	 * @since 1.0.0
	 */
	class ADSOFT_WFBT {

		/**
		 * Single instance of the class
		 *
		 * @var \ADSOFT_WFBT
		 * @since 1.0.0
		 */
		protected static $instance;

		/**
		 * Returns single instance of the class
		 *
		 * @return \ADSOFT_WFBT
		 * @since 1.0.0
		 */
		public static function get_instance(){
			if( is_null( self::$instance ) ){
				self::$instance = new self();
			}

			return self::$instance;
		}

		/**
		 * Constructor
		 *
		 * @return mixed ADSOFT_WFBT_Admin | ADSOFT_WFBT_Frontend
		 * @since 1.0.0
		 */
		public function __construct() {
			// Class admin
			if ( is_admin() ) {
				ADSOFT_WFBT_Admin();
			}

			ADSOFT_WFBT_Frontend();

			add_action( 'wp_loaded', array( $this, 'add_group_to_cart' ), 20 );
		}

		/**
		 * Add upselling group to cart
		 */
		public function add_group_to_cart(){

			if( ! ( isset( $_REQUEST[ 'adsoft_bought_together' ] ) && is_numeric( $_REQUEST[ 'adsoft_bought_together' ] ) && wp_verify_nonce( $_REQUEST[ '_wpnonce' ], 'action_bought_together' ) ) ) {
				return;
			}

			if( ! isset( $_POST['offeringID'] ) ) {
				return;
			}

			$mess = array();

			foreach( $_POST['offeringID'] as $id ) {

				$product = wc_get_product( $id );

				$attr = array();
				$variation_id = '';
				$product_id = $product->id;

				if( $product->product_type == 'variation' ) {
					$attr           = $product->get_variation_attributes();
					$variation_id   = $product->variation_id;
				}

				if( WC()->cart->add_to_cart( $product_id, 1, $variation_id, $attr ) ) {
					$mess[] = $product_id;
				}
			}

			if( ! empty( $mess ) ) {
				wc_add_to_cart_message( $mess );
			}

			if( get_option( 'woocommerce_cart_redirect_after_add' ) == 'yes' ) {
				wp_safe_redirect( WC()->cart->get_cart_url() );
				exit;
			}
			else {
				//redirect to product page
				$dest = remove_query_arg( array( 'adsoft_bought_together', '_wpnonce' ) );
				wp_redirect( esc_url( $dest ) );
				exit;
			}

		}
	}
}

/**
 * Unique access to instance of ADSOFT_WFBT class
 *
 * @return \ADSOFT_WFBT
 * @since 1.0.0
 */
function ADSOFT_WFBT(){
	return ADSOFT_WFBT::get_instance();
}